
package Google::Ads::AdWords::v201109_1::TypeMaps::AdGroupCriterionService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]' => 'Google::Ads::AdWords::v201109_1::BiddingError',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201109_1::Predicate',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201109_1::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201109_1::RateExceededError::Reason',
               'mutateResponse/rval/partialFailureErrors[RejectedError]' => 'Google::Ads::AdWords::v201109_1::RejectedError',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201109_1::SystemServingStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201109_1::ClientTermsError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/exemptionRequests' => 'Google::Ads::AdWords::v201109_1::ExemptionRequest',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupCriterionBids',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201109_1::Predicate::Operator',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201109_1::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201109_1::BetaError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201109_1::RequiredError::Reason',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201109_1::ApprovalStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201109_1::SizeLimitError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201109_1::InternalApiError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutate/operations/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::NegativeAdGroupCriterion',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201109_1::BiddingError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201109_1::DistinctError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionPage',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201109_1::ClientTermsError',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201109_1::EntityAccessDenied',
               'mutate/operations/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionBids',
               'mutateResponse/rval/partialFailureErrors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201109_1::RejectedError::Reason',
               'getResponse/rval/entries/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'getResponse/rval/entries/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/reason' => 'Google::Ads::AdWords::v201109_1::DateError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'mutate/operations/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201109_1::DatabaseError',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionError',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201109_1::RequestError::Reason',
               'mutateResponse/rval/partialFailureErrors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201109_1::UserStatus',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201109_1::Operator',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupCriterionBids',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterion',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201109_1::NotEmptyError',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201109_1::RequestError',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201109_1::PolicyViolationKey',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201109_1::AuthorizationError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionBids',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionExperimentBidMultiplier',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201109_1::NullError',
               'mutateResponse/rval/partialFailureErrors[BetaError]' => 'Google::Ads::AdWords::v201109_1::BetaError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupCriterionBids',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/reason' => 'Google::Ads::AdWords::v201109_1::SelectorError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterionExperimentData',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201109_1::RangeError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionLimitExceeded',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]' => 'Google::Ads::AdWords::v201109_1::StatsQueryError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201109_1::NotEmptyError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'mutate/operations/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthenticationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]' => 'Google::Ads::AdWords::v201109_1::CriterionError',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201109_1::RangeError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'getResponse/rval/entries/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/source' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201109_1::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201109_1::SortOrder',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionService::get',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201109_1::BetaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201109_1::SizeLimitError::Reason',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError::Part',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthenticationError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201109_1::SystemServingStatus',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201109_1::EntityNotFound::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201109_1::DistinctError::Reason',
               'mutate/operations/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError::Part',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[PagingError]' => 'Google::Ads::AdWords::v201109_1::PagingError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/reason' => 'Google::Ads::AdWords::v201109_1::BiddingError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupCriterionBids',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201109_1::NullError',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupCriterionBids',
               'mutateResponse/rval/value/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201109_1::ApprovalStatus',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupCriterionBids',
               'mutateResponse/rval/value/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201109_1::AuthenticationError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201109_1::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupCriterionBids',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[PagingError]' => 'Google::Ads::AdWords::v201109_1::PagingError',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201109_1::SystemServingStatus',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201109_1::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[DateError]' => 'Google::Ads::AdWords::v201109_1::DateError',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201109_1::PolicyViolationKey',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionService::mutate',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutateResponse/rval/value/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201109_1::BiddingError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201109_1::SizeLimitError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201109_1::QualityInfo',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionBids',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded::Reason',
               'mutate/operations/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded',
               'mutateResponse/rval/value/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201109_1::DistinctError',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]' => 'Google::Ads::AdWords::v201109_1::SelectorError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201109_1::EntityAccessDenied::Reason',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterionExperimentData',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::NegativeAdGroupCriterion',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionReturnValue',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201109_1::DatabaseError',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError::Part',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError::Reason',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201109_1::Selector',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201109_1::DistinctError',
               'getResponse/rval/entries/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201109_1::PagingError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201109_1::SelectorError',
               'mutateResponse/rval/value/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201109_1::EntityNotFound::Reason',
               'mutateResponse/rval/value/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201109_1::PolicyViolationKey',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201109_1::NotEmptyError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterion',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthorizationError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201109_1::Paging',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterion',
               'mutateResponse/rval/value/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201109_1::EntityNotFound',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/source' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'getResponse/rval/entries/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201109_1::UserStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupCriterionBids',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201109_1::ApprovalStatus',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201109_1::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/reason' => 'Google::Ads::AdWords::v201109_1::RejectedError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201109_1::StatsQueryError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201109_1::InternalApiError::Reason',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201109_1::DatabaseError::Reason',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201109_1::EntityAccessDenied::Reason',
               'mutate/operations/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201109_1::DateError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201109_1::ClientTermsError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201109_1::NullError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201109_1::MultiplierSource',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201109_1::MultiplierSource',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'getResponse' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionService::getResponse',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201109_1::StatsQueryError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201109_1::CriterionError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterion',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError::Part',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201109_1::RequiredError',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201109_1::RateExceededError',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201109_1::InternalApiError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201109_1::BiddableAdGroupCriterionExperimentData',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201109_1::SelectorError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201109_1::AuthorizationError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201109_1::QualityInfo',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/reason' => 'Google::Ads::AdWords::v201109_1::PagingError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionBids',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionBids',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupCriterionBids',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201109_1::SizeLimitError',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/reason' => 'Google::Ads::AdWords::v201109_1::CriterionError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutate/operations/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ConversionOptimizerAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201109_1::RangeError::Reason',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError::Reason',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201109_1::RequestError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201109_1::RequiredError',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201109_1::AuthenticationError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201109_1::EntityAccessDenied',
               'mutateResponse/rval/value/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded::Reason',
               'getResponse/rval/entries/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutate/operations/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutate/operations/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionService::mutateResponse',
               'mutateResponse/rval/value/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201109_1::DatabaseError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutateResponse/rval/partialFailureErrors[BetaError]/reason' => 'Google::Ads::AdWords::v201109_1::BetaError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]' => 'Google::Ads::AdWords::v201109_1::CriterionError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionExperimentBidMultiplier',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201109_1::NegativeAdGroupCriterion',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201109_1::MultiplierSource',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionError::Reason',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/exemptionRequests/key' => 'Google::Ads::AdWords::v201109_1::PolicyViolationKey',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'mutate/operations/operand/criterion' => 'Google::Ads::AdWords::v201109_1::Criterion',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201109_1::CriterionUserList',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201109_1::EntityNotFound',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval/entries/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError::Reason',
               'mutateResponse/rval/partialFailureErrors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/maxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/criterion/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupCriterionBids',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201109_1::PolicyViolationKey',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201109_1::PolicyViolationError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/proxyBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError::Reason',
               'getResponse/rval/entries/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201109_1::EntityCountLimitExceeded::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201109_1::OrderBy',
               'mutate/operations/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupCriterionBids',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Placement]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201109_1::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[BudgetOptimizerAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupCriterionBids',
               'mutateResponse/rval/partialFailureErrors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201109_1::NullError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201109_1::CriterionPolicyError',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]' => 'Google::Ads::AdWords::v201109_1::Product',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]/bidSource' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201109_1::Vertical',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bids[PercentCPAAdGroupCriterionBids]/source' => 'Google::Ads::AdWords::v201109_1::BidSource',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201109_1::CriterionUserList::MembershipStatus',
               'mutate/operations/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201109_1::CriterionUserInterest',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201109_1::Placement',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201109_1::RateExceededError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201109_1::UserStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'mutateResponse/rval/value/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201109_1::RequestError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201109_1::InternalApiError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/AdGroupCriterionBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bids[ManualCPCAdGroupCriterionBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupCriterionBids',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201109_1::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201109_1::QualityInfo',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterion',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bids[ManualCPMAdGroupCriterionBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201109_1::CriterionUse',
               'mutate/operations/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201109_1::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201109_1::RejectedError',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201109_1::ClientTermsError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterion',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201109_1::Keyword',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations' => 'Google::Ads::AdWords::v201109_1::AdGroupCriterionOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201109_1::TypeMaps::AdGroupCriterionService - typemap for AdGroupCriterionService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

